dub library

Enums

CreateTagRequestColorEnum
The color of the tag. If not provided, a random color will be used from the list: red, yellow, green, blue, purple, pink, brown.
GetCityAnalytics200ResponseInnerCountryEnum
The 2-letter country code of the city: https://d.to/geo
GetCountryAnalytics200ResponseInnerCountryEnum
The 2-letter country code: https://d.to/geo
GetLinks400ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks401ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks403ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks404ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks409ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks410ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks422ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks429ResponseErrorCodeEnum
A short code indicating the error code returned.
GetLinks500ResponseErrorCodeEnum
A short code indicating the error code returned.
TagSchemaColorEnum
The color of the tag.
WorkspaceSchemaPlanEnum
The plan of the workspace.
WorkspaceSchemaUsersInnerRoleEnum
The role of the authenticated user in the workspace.