GetBrowserAnalytics200ResponseInner class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

GetBrowserAnalytics200ResponseInner({required String browser, required num clicks})
Returns a new GetBrowserAnalytics200ResponseInner instance.
GetBrowserAnalytics200ResponseInner.fromJson(Map<String, dynamic> json)
factory

Properties

browser String
The name of the browser
final
clicks num
The number of clicks from this browser
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override