GetDeviceAnalytics200ResponseInner class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

GetDeviceAnalytics200ResponseInner({required String device, required num clicks})
Returns a new GetDeviceAnalytics200ResponseInner instance.
GetDeviceAnalytics200ResponseInner.fromJson(Map<String, dynamic> json)
factory

Properties

clicks num
The number of clicks from this device
final
device String
The name of the device
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override