GetLinks404Response class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

GetLinks404Response({required GetLinks404ResponseError error})
Returns a new GetLinks404Response instance.
GetLinks404Response.fromJson(Map<String, dynamic> json)
factory

Properties

error GetLinks404ResponseError
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override