GetLinks500ResponseError class

Annotations
  • @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)

Constructors

GetLinks500ResponseError({required GetLinks500ResponseErrorCodeEnum code, required String message, String? docUrl})
Returns a new GetLinks500ResponseError instance.
GetLinks500ResponseError.fromJson(Map<String, dynamic> json)
factory

Properties

code GetLinks500ResponseErrorCodeEnum
A short code indicating the error code returned.
final
docUrl String?
A link to our documentation with more details about this error code
final
hashCode int
The hash code for this object.
no setteroverride
message String
A human readable explanation of what went wrong.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override